<?php
/**
 * la language file
 *
 * This file was initially built by fetching translations from other
 * Wiki projects. See the @url lines below. Additional translations
 * and fixes where done for DokuWiki by the people mentioned in the
 * lines starting with @author
 *
 * @url http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/languages/messages/MessagesLa.php?view=co
 * @author Massimiliano Vassalli <vassalli.max@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '"';
$lang['doublequoteclosing']    = '"';
$lang['singlequoteopening']    = '`';
$lang['singlequoteclosing']    = '\'';
$lang['apostrophe']            = '´';
$lang['btn_edit']              = 'Recensere hanc paginam';
$lang['btn_source']            = 'Fontem uidere';
$lang['btn_show']              = 'Ostendere paginam';
$lang['btn_create']            = 'Creare paginam';
$lang['btn_search']            = 'Quaerere';
$lang['btn_save']              = 'Seruare';
$lang['btn_preview']           = 'Praeuidere';
$lang['btn_top']               = 'I ad summa';
$lang['btn_newer']             = '<< recentiores';
$lang['btn_older']             = 'minus recentiores >>';
$lang['btn_revs']              = 'Veteres renouationes';
$lang['btn_recent']            = 'Nuper mutata';
$lang['btn_upload']            = 'Onerare';
$lang['btn_cancel']            = 'Abrogare';
$lang['btn_index']             = 'Index';
$lang['btn_secedit']           = 'Recensere';
$lang['btn_login']             = 'Conuentum aperire';
$lang['btn_logout']            = 'Conuentum concludere';
$lang['btn_admin']             = 'Rector';
$lang['btn_update']            = 'Nouare';
$lang['btn_delete']            = 'Delere';
$lang['btn_back']              = 'Redire';
$lang['btn_backlink']          = 'Nexus ad paginam';
$lang['btn_backtomedia']       = 'Ad media redire';
$lang['btn_subscribe']         = 'Custodire';
$lang['btn_profile']           = 'Tabellam nouare';
$lang['btn_reset']             = 'Abrogare';
$lang['btn_draft']             = 'Propositum recensere';
$lang['btn_recover']           = 'Propositum reficere';
$lang['btn_draftdel']          = 'Propositum delere';
$lang['btn_revert']            = 'Reficere';
$lang['btn_register']          = 'Te adscribere';
$lang['loggedinas']            = 'Nomen sodalis:';
$lang['user']                  = 'Nomen sodalis:';
$lang['pass']                  = 'Tessera tua';
$lang['newpass']               = 'Tessera noua';
$lang['oldpass']               = 'Tessera uetus:';
$lang['passchk']               = 'Tesseram tuam adfirmare';
$lang['remember']              = 'Tesseram meam sodalitatis memento';
$lang['fullname']              = 'Nomen tuom uerum:';
$lang['email']                 = 'Cursus interretialis:';
$lang['profile']               = 'Tabella Sodalis';
$lang['badlogin']              = 'Error in ineundo est, rectum nomen uel tessera cedo.';
$lang['minoredit']             = 'Recensio minor';
$lang['draftdate']             = 'Propositum seruatur die:';
$lang['nosecedit']             = 'Pagina interea mutatur, pars rerum exiit, in loco eius tota pagina reclamata est.';
$lang['regmissing']            = 'Omnes campi complendi sunt.';
$lang['reguexists']            = 'Nomen Sodalis ab aliquo iam elegitur.';
$lang['regsuccess']            = 'Adscriptio feliciter perficitur et tessera cursu interretiali mittitur';
$lang['regsuccess2']           = 'Adscriptio perficitur';
$lang['regmailfail']           = 'Error in litteras mittendo est. Rectorem conueni!';
$lang['regbadmail']            = 'Cursus interretialis non legitimus: si errorem putes, Rectorem conueni.';
$lang['regbadpass']            = 'Tesserae quas scripsisti inter se non congruont.';
$lang['regpwmail']             = 'Tessera Dokuuicis tuam';
$lang['reghere']               = 'Non iam adscriptus\a esne? Te adscribe';
$lang['profna']                = 'Tabellam tuam mutare non potes.';
$lang['profnochange']          = 'Si res non mutare uis, nihil agere';
$lang['profnoempty']           = 'Omnes campi complendi sunt.';
$lang['profchanged']           = 'Tabella Sodalis feliciter nouatur';
$lang['pwdforget']             = 'Tesseram amisistine? Nouam petere';
$lang['resendna']              = 'Tesseram non mutare potest.';
$lang['resendpwdmissing']      = 'Omnes campi complendi sunt.';
$lang['resendpwdnouser']       = 'In tabellis Sodalium nomen non inuentum est.';
$lang['resendpwdbadauth']      = 'Tesseram non legitima est.';
$lang['resendpwdconfirm']      = 'Confirmatio cursu interretiali mittitur.';
$lang['resendpwdsuccess']      = 'Tessera noua cursu interretiali mittitur.';
$lang['license']               = 'Praeter ubi adnotatum, omnia scripta Corporis Gentis Latinae cum his facultatibus:';
$lang['licenseok']             = 'Caue: si paginam recenseas, has facultates confirmas:';
$lang['searchmedia']           = 'Quaere titulum:';
$lang['searchmedia_in']        = 'Quaere "%s":';
$lang['txt_upload']            = 'Eligere documenta oneranda:';
$lang['txt_filename']          = 'Onerare (optio):';
$lang['txt_overwrt']           = 'Documento ueteri imponere:';
$lang['lockedby']              = 'Nunc hoc intercludit';
$lang['lockexpire']            = 'Hoc apertum';
$lang['js']['willexpire']            = 'Interclusio paginae recensendae uno minuto finita est.\nUt errores uites, \'praeuisio\' preme ut interclusionem ripristines.';
$lang['js']['notsavedyet']     = 'Res non seruatae amissurae sunt.';
$lang['js']['searchmedia']     = 'Quaere inter documenta';
$lang['js']['keepopen']        = 'Fenestram apertam tene';
$lang['js']['hidedetails']     = 'Singulas res abscondere';
$lang['js']['mediatitle']      = 'Optiones nexorum';
$lang['js']['mediadisplay']    = 'Genus nexi';
$lang['js']['mediaalign']      = 'Collocatio';
$lang['js']['mediasize']       = 'Amplitudo imaginis';
$lang['js']['mediatarget']     = 'Cui nexum est';
$lang['js']['mediaclose']      = 'Claudere';
$lang['js']['mediainsert']     = 'Insere';
$lang['js']['mediadisplayimg'] = 'Imaginem ostendere';
$lang['js']['mediadisplaylnk'] = 'Solum nexum ostendere';
$lang['js']['mediasmall']      = 'Forma minor';
$lang['js']['mediamedium']     = 'Forma media';
$lang['js']['medialarge']      = 'Forma maior';
$lang['js']['mediaoriginal']   = 'Forma primigenia';
$lang['js']['medialnk']        = 'Singulis rebus paginae nexum';
$lang['js']['mediadirect']     = 'Primigeniae formae nexum';
$lang['js']['medianolnk']      = 'Connectio deest';
$lang['js']['medianolink']     = 'Imaginem non connectere';
$lang['js']['medialeft']       = 'Imaginem ad sinistram collocare';
$lang['js']['mediaright']      = 'Imaginem ad dextram collocare';
$lang['js']['mediacenter']     = 'Imaginem in mediam collocare';
$lang['js']['medianoalign']    = 'Collocationem remouere';
$lang['js']['nosmblinks']      = 'Windows nexa solum cum Microsoft Internet Explorer ostendi possunt.
Adhuc transcribere nexum potes.';
$lang['js']['linkwiz']         = 'Connectendi ductor';
$lang['js']['linkto']          = 'Nexum ad:';
$lang['js']['del_confirm']     = 'Delere electas res uin?';
$lang['rssfailed']             = 'Error in restituendo ';
$lang['nothingfound']          = 'Nihil inuentum est.';
$lang['mediaselect']           = 'Documenta uisiua:';
$lang['fileupload']            = 'Documentum uisiuom onerare';
$lang['uploadsucc']            = 'Oneratum perfectum';
$lang['uploadfail']            = 'Error onerandi.';
$lang['uploadwrong']           = 'Onerare non potest. Genus documenti non legitimum!';
$lang['uploadexist']           = 'Documentum iam est.';
$lang['uploadbadcontent']      = 'Documentum oneratum cum genere documenti non congruit.';
$lang['uploadspam']            = 'Onerare non potest: nam in indice perscriptionis documentum est.';
$lang['uploadxss']             = 'Onerare non potest: nam forsitan malum scriptum in documento est.';
$lang['uploadsize']            = 'Documentum onerandum ponderosius est. (Maxime "%s")';
$lang['deletesucc']            = 'Documentum "%s" deletum est.';
$lang['deletefail']            = '"%s" non deletur: uide facultates.';
$lang['mediainuse']            = 'documentum "%s" non deletur, nam aliquis hoc utitur.';
$lang['namespaces']            = 'Genus';
$lang['mediafiles']            = 'Documentum liberum in:';
$lang['accessdenied']          = 'Non uidere documentum potes.';
$lang['mediausage']            = 'Hac forma uteris ut documentum referas:';
$lang['mediaview']             = 'Vide documentum primigenium';
$lang['mediaroot']             = 'scrinium';
$lang['mediaupload']           = 'Hic genus oneras. Si nouom genus creare uis, ante "Onerare ut" nomen documenti diuisum a duabus punctis ponas.';
$lang['mediaextchange']        = 'Genus documenti mutatum a(b) ".%s" ad ".%s"!';
$lang['reference']             = 'Referre:';
$lang['ref_inuse']             = 'Documentum non deleri potest, nam in his paginis apertum est:';
$lang['ref_hidden']            = 'Aliquae mentiones ad paginas, ad quas ire non potes, habent';
$lang['hits']                  = 'Ictus';
$lang['quickhits']             = 'Spatium nominis conguens';
$lang['toc']                   = 'Index';
$lang['current']               = 'nouos\a\um';
$lang['yours']                 = 'Tua forma';
$lang['diff']                  = 'Discrimina inter formas ostendere';
$lang['diff2']                 = 'Discrimina inter electas recensiones ostendere';
$lang['difflink']              = 'Nexum ad comparandum';
$lang['line']                  = 'Linea';
$lang['breadcrumb']            = 'Vestigium';
$lang['youarehere']            = 'Hic es';
$lang['lastmod']               = 'Extrema mutatio';
$lang['by']                    = 'a(b)';
$lang['deleted']               = 'deletur';
$lang['created']               = 'creatur';
$lang['restored']              = 'Recensio uetus restituta';
$lang['external_edit']         = 'Externe recensere';
$lang['summary']               = 'Indicem recensere';
$lang['noflash']               = '<a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> necessarium est.';
$lang['download']              = 'Snippet capere';
$lang['mail_newpage']          = 'Pagina addita:';
$lang['mail_changed']          = 'Pagina mutata:';
$lang['mail_subscribe_list']   = 'Paginae in genere mutatae:';
$lang['mail_new_user']         = 'Nouos Sodalis:';
$lang['mail_upload']           = 'Documentum oneratum:';
$lang['qb_bold']               = 'Litterae pingues';
$lang['qb_italic']             = 'Litterae italicae';
$lang['qb_underl']             = 'Litterae sullineatae';
$lang['qb_code']               = 'Codex scripti';
$lang['qb_strike']             = 'Litterae illineatae';
$lang['qb_h1']                 = 'Caput I';
$lang['qb_h2']                 = 'Caput II';
$lang['qb_h3']                 = 'Caput III';
$lang['qb_h4']                 = 'Caput IV';
$lang['qb_h5']                 = 'Caput V';
$lang['qb_h']                  = 'Caput';
$lang['qb_hs']                 = 'Caput eligere';
$lang['qb_hplus']              = 'Caput maius';
$lang['qb_hminus']             = 'Caput minus';
$lang['qb_hequal']             = 'Caput eiusdem gradus';
$lang['qb_link']               = 'Nexus internus';
$lang['qb_extlink']            = 'Nexus externus (memento praefigere http://)';
$lang['qb_hr']                 = 'Linea directa (noli saepe uti)';
$lang['qb_ol']                 = 'Index ordinatus rerum';
$lang['qb_ul']                 = 'Index non ordinatus rerum';
$lang['qb_media']              = 'Imagines et documenta addere';
$lang['qb_sig']                = 'Subscriptio tua cum indicatione temporis';
$lang['qb_smileys']            = 'Pupuli';
$lang['qb_chars']              = 'Signa singularia';
$lang['upperns']               = 'I ad anterius genus';
$lang['admin_register']        = 'Nouom Sodalem creare';
$lang['metaedit']              = 'Res codicis mutare';
$lang['metasaveerr']           = 'Res codicis non scribitur.';
$lang['metasaveok']            = 'Res codicis seruatae.';
$lang['img_backto']            = 'Redere ad';
$lang['img_title']             = 'Titulus';
$lang['img_caption']           = 'Descriptio';
$lang['img_date']              = 'Dies';
$lang['img_fname']             = 'Titulus documenti';
$lang['img_fsize']             = 'Pondus';
$lang['img_artist']            = 'Imaginum exprimitor\trix';
$lang['img_copyr']             = 'Iura exemplarium';
$lang['img_format']            = 'Forma';
$lang['img_camera']            = 'Cella';
$lang['img_keywords']          = 'Verba claues';
$lang['subscr_subscribe_success'] = '%s additur indici subscriptionis quod %s';
$lang['subscr_subscribe_error'] = '%s non additur indici subscriptionis quod %s';
$lang['subscr_subscribe_noaddress'] = 'Cursus interretialis tuus deest, sic in indice subscriptionis non scribi potes';
$lang['subscr_unsubscribe_success'] = 'A subscriptione %s deletur quod %s';
$lang['subscr_unsubscribe_error'] = 'Error delendi %s a subscriptione quod %s';
$lang['subscr_already_subscribed'] = '%s iam subscriptus\a est in %s';
$lang['subscr_not_subscribed'] = '%s non subscriptus\a est in %s';
$lang['subscr_m_not_subscribed'] = 'Non hanc paginam uel genus subscribere potes.';
$lang['subscr_m_new_header']   = 'Subscriptionem addere';
$lang['subscr_m_current_header'] = 'haec subscriptio:';
$lang['subscr_m_unsubscribe']  = 'Delere';
$lang['subscr_m_subscribe']    = 'Subscribere';
$lang['subscr_m_receive']      = 'Accipere';
$lang['subscr_style_every']    = 'Cursus mutationibus omnibus';
$lang['subscr_style_digest']   = 'Accipere litteras in mutando paginam (%.2f dies)';
$lang['subscr_style_list']     = 'Index mutatarum paginarum ab extremis litteris (%.2f dies)';
$lang['authmodfailed']         = 'Confirmatio infeliciter facta est. Rectorem conuenis.';
$lang['authtempfail']          = 'Confirmare non potes. Rectorem conuenis.';
$lang['i_chooselang']          = 'Linguam eligere';
$lang['i_installer']           = 'Docuuicis creator';
$lang['i_wikiname']            = 'Nomen Vicis';
$lang['i_enableacl']           = 'ICA aptum facias (consulatum est)';
$lang['i_superuser']           = 'Magister\stra';
$lang['i_problems']            = 'Creator hos errores habes. Continuare potes postquam omnia soluentur.';
$lang['i_modified']            = 'Hoc scriptum solum cum noua forma Dokuuicis est. Hoc rursum capere in pagina, in qua haec machina capta est, potes aut i ad <a href="http://dokuwiki.org/install">Dokuuicis installation instructions</a>';
$lang['i_funcna']              = 'PHP functio <code>%s</code> inepta est.';
$lang['i_phpver']              = 'Forma tua PHP <code>%s</code> minor quam illa necessaria <code>%s</code>.';
$lang['i_permfail']            = '<code>%s</code> non a uice scribitur. Facultates inspicere.';
$lang['i_confexists']          = '<code>%s</code> iam est.';
$lang['i_writeerr']            = '<code>%s</code> non creari potest. Manu illum creas.';
$lang['i_badhash']             = 'Ignotum uel mutatum dokuwiki.php (<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> non legitimum uel uacuom';
$lang['i_success']             = 'Administratio feliciter perficitur. Delere install.php documentum potes. I ad <a href="doku.php">hanc paginam</a> ut continues.';
$lang['i_failure']             = 'Aliqui errores dum documenta administrantur sunt. Manu onerare omnes potes priusquam <a href="doku.php">tuo nouo uice</a> uteris.';
$lang['i_policy']              = 'ICA ratio prima';
$lang['i_pol0']                = 'Vicem aperire (omnes legere, scribere, onerare possunt)';
$lang['i_pol1']                = 'Publicus uicis (omnes legere, Sodales scribere et onerare possunt)';
$lang['i_pol2']                = 'Clausus uicis (Soli Sodales legere scribere et onerare poccunt)';
$lang['i_retry']               = 'Rursum temptas';
$lang['i_license']             = 'Elige facultatem sub qua tuus uicis est:';
$lang['recent_global']         = 'Mutatione in hoc genere uides. Recentiores mutationes quoque uidere <a href="%s">potes</a>';
$lang['years']                 = 'ab annis %d';
$lang['months']                = 'a mensibus %d';
$lang['weeks']                 = 'a septimanis %d';
$lang['days']                  = 'a diebus %d';
$lang['hours']                 = 'a horis %d';
$lang['minutes']               = 'a minutis %d';
$lang['seconds']               = 'a secundis %d';
$lang['wordblock']             = 'Mutationes non seruantur, eo quod mala uerba contenit';
